# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_WARPED_GRID_IMAGE_METADATA = Metadata(
    id="43b75b2bbf1de43489ea85a551208078dcde662b.boutiques",
    name="CreateWarpedGridImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class CreateWarpedGridImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_warped_grid_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warped_grid_image: OutputPathType
    """The resultant warped grid image."""


def create_warped_grid_image(
    image_dimension: int,
    deformation_field: InputPathType,
    output_image: str,
    directions: str | None = None,
    grid_spacing: str | None = None,
    grid_sigma: str | None = None,
    runner: Runner | None = None,
) -> CreateWarpedGridImageOutputs:
    """
    Create a warped grid image based on the specified deformation field.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the input image.
        deformation_field: File containing the deformation field to be applied.
        output_image: The filename of the output warped grid image.
        directions: Directions for the grid warping, e.g., '1x0x0'.
        grid_spacing: Spacing of the grid, e.g., '10x10x10'.
        grid_sigma: Sigma value for the grid smoothing, e.g., '1x1x1'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateWarpedGridImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_WARPED_GRID_IMAGE_METADATA)
    cargs = []
    cargs.append("CreateWarpedGridImage")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(deformation_field))
    cargs.append(output_image)
    if directions is not None:
        cargs.append(directions)
    if grid_spacing is not None:
        cargs.append(grid_spacing)
    if grid_sigma is not None:
        cargs.append(grid_sigma)
    ret = CreateWarpedGridImageOutputs(
        root=execution.output_file("."),
        warped_grid_image=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_WARPED_GRID_IMAGE_METADATA",
    "CreateWarpedGridImageOutputs",
    "create_warped_grid_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_STATS_AC_METADATA = Metadata(
    id="38bce967cfc9907f2f4aad1d1246fa98b24d0792.boutiques",
    name="dmri_stats_ac",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriStatsAcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_stats_ac(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output of the dMRI statistical analysis"""


def dmri_stats_ac(
    anatomicuts_folder: str,
    num_clusters: int,
    correspondence_file: str,
    measures: list[str],
    output_file: str,
    runner: Runner | None = None,
) -> DmriStatsAcOutputs:
    """
    The tool 'dmri_stats_ac' performs statistical analysis on dMRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        anatomicuts_folder: Input folder containing anatomicuts data.
        num_clusters: Number of clusters for analysis.
        correspondence_file: File specifying correspondence details.
        measures: Number of measures followed by each measure name and file.
        output_file: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriStatsAcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_STATS_AC_METADATA)
    cargs = []
    cargs.append("dmri_stats_ac")
    cargs.extend([
        "-i",
        anatomicuts_folder
    ])
    cargs.extend([
        "-n",
        str(num_clusters)
    ])
    cargs.extend([
        "-c",
        correspondence_file
    ])
    cargs.append("-m")
    cargs.append("[NUM_MEASURES]")
    cargs.extend([
        "-m",
        *measures
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    ret = DmriStatsAcOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_STATS_AC_METADATA",
    "DmriStatsAcOutputs",
    "dmri_stats_ac",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RMSDIFF_METADATA = Metadata(
    id="721e867f6f94c898ce8453a6c1d46d329b31f94e.boutiques",
    name="rmsdiff",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class RmsdiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rmsdiff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rmsdiff(
    matrixfile1: InputPathType,
    matrixfile2: InputPathType,
    refvol: InputPathType,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> RmsdiffOutputs:
    """
    Outputs RMS deviation between matrices (in mm).
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        matrixfile1: First matrix file.
        matrixfile2: Second matrix file.
        refvol: Reference volume.
        mask: Optional mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RmsdiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RMSDIFF_METADATA)
    cargs = []
    cargs.append("rmsdiff")
    cargs.append(execution.input_file(matrixfile1))
    cargs.append(execution.input_file(matrixfile2))
    cargs.append(execution.input_file(refvol))
    if mask is not None:
        cargs.append(execution.input_file(mask))
    ret = RmsdiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RMSDIFF_METADATA",
    "RmsdiffOutputs",
    "rmsdiff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LISTSUBJ_METADATA = Metadata(
    id="e9369381138405e14a70273bc76d2a91dd2f8045.boutiques",
    name="listsubj",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ListsubjOutputs(typing.NamedTuple):
    """
    Output object returned when calling `listsubj(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def listsubj(
    subject_dir: str,
    runner: Runner | None = None,
) -> ListsubjOutputs:
    """
    List subject IDs in SUBJECT_DIR.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Directory where subjects are stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ListsubjOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LISTSUBJ_METADATA)
    cargs = []
    cargs.append("listsubj")
    cargs.append("[OPTIONS]")
    cargs.append(subject_dir)
    ret = ListsubjOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LISTSUBJ_METADATA",
    "ListsubjOutputs",
    "listsubj",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_5_0_2_XYZTRANS_SCH_METADATA = Metadata(
    id="97a334fb37fbd008c00e7f8cd6895c30829fe6b3.boutiques",
    name="fsl.5.0.2.xyztrans.sch",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Fsl502XyztransSchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_5_0_2_xyztrans_sch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_5_0_2_xyztrans_sch(
    term_option: str | None = None,
    version_flag: bool = False,
    no_scrollback_flag: bool = False,
    runner: Runner | None = None,
) -> Fsl502XyztransSchOutputs:
    """
    A script with unclear functionality, potentially related to terminal operations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        term_option: Use this instead of the $TERM environment variable.
        version_flag: Print the curses library version used.
        no_scrollback_flag: Do not try to clear the scrollback buffer.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fsl502XyztransSchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_5_0_2_XYZTRANS_SCH_METADATA)
    cargs = []
    cargs.append("fsl.5.0.2.xyztrans.sch")
    if term_option is not None:
        cargs.extend([
            "-T",
            term_option
        ])
    if version_flag:
        cargs.append("-V")
    if no_scrollback_flag:
        cargs.append("-x")
    ret = Fsl502XyztransSchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_5_0_2_XYZTRANS_SCH_METADATA",
    "Fsl502XyztransSchOutputs",
    "fsl_5_0_2_xyztrans_sch",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DFT_METADATA = Metadata(
    id="a3b7d9976a6067e83188d375554ab6efc38583c7.boutiques",
    name="3dDFT",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDftOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_dft(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output dataset file"""
    outheader: OutputPathType
    """Output dataset header file"""


def v_3d_dft(
    infile: InputPathType,
    prefix: str,
    abs_output: bool = False,
    nfft: float | None = None,
    detrend: bool = False,
    taper: float | None = None,
    inverse: bool = False,
    runner: Runner | None = None,
) -> V3dDftOutputs:
    """
    Performs Discrete Fourier Transform (DFT) along the time axis of a complex- or
    float-valued dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input dataset (complex- or float-valued).
        prefix: Prefix for the output file.
        abs_output: Output float dataset = abs(DFT).
        nfft: DFT length (must be >= number of time points).
        detrend: Least-squares remove linear drift before DFT.
        taper: Fraction (0 <= f <= 1) of data to taper at ends (Hamming taper).
        inverse: Perform the inverse DFT.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDftOutputs`).
    """
    if taper is not None and not (0.0 <= taper <= 1.0): 
        raise ValueError(f"'taper' must be between 0.0 <= x <= 1.0 but was {taper}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DFT_METADATA)
    cargs = []
    cargs.append("3dDFT")
    cargs.append(execution.input_file(infile))
    cargs.extend([
        "-prefix",
        prefix
    ])
    if abs_output:
        cargs.append("-abs")
    if nfft is not None:
        cargs.extend([
            "-nfft",
            str(nfft)
        ])
    if detrend:
        cargs.append("-detrend")
    if taper is not None:
        cargs.extend([
            "-taper",
            str(taper)
        ])
    if inverse:
        cargs.append("-inverse")
    ret = V3dDftOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(prefix + "+orig.BRIK"),
        outheader=execution.output_file(prefix + "+orig.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDftOutputs",
    "V_3D_DFT_METADATA",
    "v_3d_dft",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABELS_INTERSECT_METADATA = Metadata(
    id="1e2c55cb0005072264aed23aaa37a59486e7c119.boutiques",
    name="labels_intersect",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LabelsIntersectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `labels_intersect(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_label: OutputPathType
    """The resulting intersected label file"""


def labels_intersect(
    label1: InputPathType,
    label2: InputPathType,
    outputname: str,
    runner: Runner | None = None,
) -> LabelsIntersectOutputs:
    """
    Tool to find the intersection of two label files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label1: First input label file.
        label2: Second input label file.
        outputname: Output label file name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelsIntersectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABELS_INTERSECT_METADATA)
    cargs = []
    cargs.append("labels_intersect")
    cargs.append(execution.input_file(label1))
    cargs.append(execution.input_file(label2))
    cargs.append(outputname)
    ret = LabelsIntersectOutputs(
        root=execution.output_file("."),
        output_label=execution.output_file(outputname),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABELS_INTERSECT_METADATA",
    "LabelsIntersectOutputs",
    "labels_intersect",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIDUCIALS_CORRECTION_METADATA = Metadata(
    id="4c8ff34a05a460d57cf9bd6ab63606fa5145834f.boutiques",
    name="fiducials_correction",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FiducialsCorrectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fiducials_correction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file with corrected fiducial markers."""


def fiducials_correction(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> FiducialsCorrectionOutputs:
    """
    A tool for correcting fiducial markers in imaging data. Note: This command has
    dependency issues with the Qt platform plugin 'xcb'. Ensure dependencies are
    properly configured.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input file containing imaging data with fiducial markers to\
            correct.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FiducialsCorrectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIDUCIALS_CORRECTION_METADATA)
    cargs = []
    cargs.append("fiducials_correction")
    cargs.append(execution.input_file(input_file))
    cargs.append("[OUTPUT_FILE]")
    ret = FiducialsCorrectionOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIDUCIALS_CORRECTION_METADATA",
    "FiducialsCorrectionOutputs",
    "fiducials_correction",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FVCOMPARE_METADATA = Metadata(
    id="84e27ef54cc73075db70cca3ebbdd40631c9472d.boutiques",
    name="fvcompare",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FvcompareOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fvcompare(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fvcompare(
    subject1: str,
    subject2: str,
    subject_dir1: str | None = None,
    subject_dir2: str | None = None,
    name1: str | None = None,
    name2: str | None = None,
    color1: str | None = None,
    volume: str | None = None,
    segmentation: str | None = None,
    aseg: bool = False,
    no_seg: bool = False,
    right_hemi: bool = False,
    no_surf: bool = False,
    gray_levels: list[float] | None = None,
    cursor_position: list[float] | None = None,
    zoom_level: float | None = None,
    annotation: str | None = None,
    aparc: bool = False,
    inflated: bool = False,
    white: bool = False,
    orig: bool = False,
    surf_name: str | None = None,
    pointset: InputPathType | None = None,
    wot2: bool = False,
    runner: Runner | None = None,
) -> FvcompareOutputs:
    """
    Simultaneously loads volume, segmentation, and surface data from two subjects in
    freeview, for comparing across time or different analysis methods.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject1: Subject 1 identifier.
        subject2: Subject 2 identifier.
        subject_dir1: Directory path for Subject 1.
        subject_dir2: Directory path for Subject 2.
        name1: Name associated with Subject 1 (default: s1).
        name2: Name associated with Subject 2 (default: s2).
        color1: Set surface colors for Subject 1.
        volume: Volume name found in subject/mri (default: brainmask.mgz, can\
            have multiple).
        segmentation: Segmentation name found in subject/mri (default:\
            aparc+aseg.mgz, can have multiple).
        aseg: Add aseg.mgz to segmentation list.
        no_seg: Do not display segmentations.
        right_hemi: Only display right hemisphere.
        no_surf: Do not display surfaces.
        gray_levels: Set gray scale levels.
        cursor_position: Place cursor at given location and center Field of\
            View.
        zoom_level: Set zoom level.
        annotation: Load annotation onto surfaces.
        aparc: Load aparc.annot onto surfaces.
        inflated: Load inflated surfaces in addition to white and pial.
        white: Only show white surfaces.
        orig: Only show orig.nofix and orig surfaces.
        surf_name: Only show specified surface name.
        pointset: Load point set file.
        wot2: Include the ?h.woT2.pial surfs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FvcompareOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FVCOMPARE_METADATA)
    cargs = []
    cargs.append("fvcompare")
    cargs.extend([
        "--s1",
        subject1
    ])
    cargs.extend([
        "--s2",
        subject2
    ])
    if subject_dir1 is not None:
        cargs.extend([
            "--sd1",
            subject_dir1
        ])
    if subject_dir2 is not None:
        cargs.extend([
            "--sd2",
            subject_dir2
        ])
    if name1 is not None:
        cargs.extend([
            "--n1",
            name1
        ])
    if name2 is not None:
        cargs.extend([
            "--n2",
            name2
        ])
    if color1 is not None:
        cargs.extend([
            "--c1",
            color1
        ])
    if volume is not None:
        cargs.extend([
            "--vol",
            volume
        ])
    if segmentation is not None:
        cargs.extend([
            "--seg",
            segmentation
        ])
    if aseg:
        cargs.append("--aseg")
    if no_seg:
        cargs.append("--no-seg")
    if right_hemi:
        cargs.append("--rh")
    if no_surf:
        cargs.append("--no-surf")
    if gray_levels is not None:
        cargs.extend([
            "--gray",
            *map(str, gray_levels)
        ])
    if cursor_position is not None:
        cargs.extend([
            "--crs",
            *map(str, cursor_position)
        ])
    if zoom_level is not None:
        cargs.extend([
            "--zoom",
            str(zoom_level)
        ])
    if annotation is not None:
        cargs.extend([
            "--annot",
            annotation
        ])
    if aparc:
        cargs.append("--aparc")
    if inflated:
        cargs.append("--inflated")
    if white:
        cargs.append("--white")
    if orig:
        cargs.append("--orig")
    if surf_name is not None:
        cargs.extend([
            "--surf",
            surf_name
        ])
    if pointset is not None:
        cargs.extend([
            "--p",
            execution.input_file(pointset)
        ])
    if wot2:
        cargs.append("--wot2")
    ret = FvcompareOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FVCOMPARE_METADATA",
    "FvcompareOutputs",
    "fvcompare",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_AVERAGE_SUBCORT_METADATA = Metadata(
    id="0c9ffded4567106d920f42e12c804ae17630eddc.boutiques",
    name="make_average_subcort",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeAverageSubcortOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_average_subcort(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask_file: OutputPathType
    """Final average subcortical mask in fsaverage/mni305 space"""


def make_average_subcort(
    subjects: list[str],
    output_volume: str,
    runner: Runner | None = None,
) -> MakeAverageSubcortOutputs:
    """
    This creates an average subcortical mask for the given input subjects, intended
    for use in subcortical analysis in FSFAST to exclude cortical voxels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subject identifiers.
        output_volume: Output volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeAverageSubcortOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_AVERAGE_SUBCORT_METADATA)
    cargs = []
    cargs.append("make_average_subcort")
    cargs.extend(subjects)
    cargs.extend([
        "--o",
        output_volume
    ])
    ret = MakeAverageSubcortOutputs(
        root=execution.output_file("."),
        output_mask_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_AVERAGE_SUBCORT_METADATA",
    "MakeAverageSubcortOutputs",
    "make_average_subcort",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICETIMER_METADATA = Metadata(
    id="0643001d0af973bc2b812f49825965703708a3cb.boutiques",
    name="slicetimer",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SlicetimerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicetimer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_timeseries: OutputPathType | None
    """Output timeseries"""


def slicetimer(
    infile: InputPathType,
    outfile: InputPathType | None = None,
    verbose_flag: bool = False,
    down_flag: bool = False,
    tr_value: float | None = None,
    direction: str | None = None,
    odd_flag: bool = False,
    tcustom_file: InputPathType | None = None,
    tglobal_value: float | None = None,
    ocustom_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> SlicetimerOutputs:
    """
    FMRIB's Interpolation for Slice Timing.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Filename of input timeseries.
        outfile: Filename of output timeseries.
        verbose_flag: Switch on diagnostic messages.
        down_flag: Reverse slice indexing (default is: slices were acquired\
            bottom-up).
        tr_value: Specify TR of data - default is 3s.
        direction: Direction of slice acquisition (x=1,y=2,z=3) - default is z.
        odd_flag: Use interleaved acquisition.
        tcustom_file: Filename of single-column slice timings, in fractions of\
            TR, +ve values shift slices forward in time.
        tglobal_value: Global shift in fraction of TR, (default is 0).
        ocustom_file: Filename of single-column custom interleave order file\
            (first slice is referred to as 1 not 0).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicetimerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICETIMER_METADATA)
    cargs = []
    cargs.append("slicetimer")
    cargs.extend([
        "-i",
        execution.input_file(infile)
    ])
    if outfile is not None:
        cargs.extend([
            "-o",
            execution.input_file(outfile)
        ])
    if verbose_flag:
        cargs.append("-v")
    if down_flag:
        cargs.append("--down")
    if tr_value is not None:
        cargs.extend([
            "-r",
            str(tr_value)
        ])
    if direction is not None:
        cargs.extend([
            "-d",
            direction
        ])
    if odd_flag:
        cargs.append("--odd")
    if tcustom_file is not None:
        cargs.extend([
            "--tcustom",
            execution.input_file(tcustom_file)
        ])
    if tglobal_value is not None:
        cargs.extend([
            "--tglobal",
            str(tglobal_value)
        ])
    if ocustom_file is not None:
        cargs.extend([
            "--ocustom",
            execution.input_file(ocustom_file)
        ])
    ret = SlicetimerOutputs(
        root=execution.output_file("."),
        output_timeseries=execution.output_file(pathlib.Path(outfile).name) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICETIMER_METADATA",
    "SlicetimerOutputs",
    "slicetimer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_BRAIN_VOLUME_METADATA = Metadata(
    id="2918ea0c5a20422d8241bcf06406d8027e4e4dae.boutiques",
    name="mri_brain_volume",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriBrainVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_brain_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType | None
    """Output file containing brain volume information"""


def mri_brain_volume(
    input_file: InputPathType,
    output_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriBrainVolumeOutputs:
    """
    Tool to calculate brain volume from MRI scans.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input MRI file.
        output_file: Output file for brain volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriBrainVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_BRAIN_VOLUME_METADATA)
    cargs = []
    cargs.append("mri_brain_volume")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_file))
    if output_file is not None:
        cargs.append(execution.input_file(output_file))
    ret = MriBrainVolumeOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_BRAIN_VOLUME_METADATA",
    "MriBrainVolumeOutputs",
    "mri_brain_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REMOVE_VARIANCE_METADATA = Metadata(
    id="179ff3984d2be9f6ba0b11909b268c8560dc15ee.boutiques",
    name="mris_remove_variance",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRemoveVarianceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_remove_variance(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resulting_curvature_file: OutputPathType
    """The resulting curvature file after removing variance."""


def mris_remove_variance(
    input_surface_file: InputPathType,
    curvature_file: InputPathType,
    curvature_file_to_remove: InputPathType,
    output_curvature_file: str,
    runner: Runner | None = None,
) -> MrisRemoveVarianceOutputs:
    """
    This program removes the linear component of the variance accounted for by one
    curvature vector from another.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface_file: The input surface file.
        curvature_file: The curvature file.
        curvature_file_to_remove: The curvature file to remove from the input\
            curvature.
        output_curvature_file: The output curvature file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRemoveVarianceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REMOVE_VARIANCE_METADATA)
    cargs = []
    cargs.append("mris_remove_variance")
    cargs.append(execution.input_file(input_surface_file))
    cargs.append(execution.input_file(curvature_file))
    cargs.append(execution.input_file(curvature_file_to_remove))
    cargs.append(output_curvature_file)
    ret = MrisRemoveVarianceOutputs(
        root=execution.output_file("."),
        resulting_curvature_file=execution.output_file(output_curvature_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REMOVE_VARIANCE_METADATA",
    "MrisRemoveVarianceOutputs",
    "mris_remove_variance",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CURVATURE_METADATA = Metadata(
    id="b2be5c74ffe0d5cc95cc6e6fc9fb27e6b3355ec4.boutiques",
    name="mris_curvature",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCurvatureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_curvature(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mean_curvature: OutputPathType
    """Mean curvature file"""
    gaussian_curvature: OutputPathType
    """Gaussian curvature file"""


def mris_curvature(
    input_surface: InputPathType,
    save_curvature_files: bool = False,
    max_principal_curvature: bool = False,
    mgh_output_format: bool = False,
    min_principal_curvature: bool = False,
    iterative_averages: float | None = None,
    neighborhood_size: float | None = None,
    random_seed: float | None = None,
    curvatures: str | None = None,
    h_curvature: str | None = None,
    k_curvature: str | None = None,
    k1_curvature: str | None = None,
    k2_curvature: str | None = None,
    k1k2_curvature: str | None = None,
    runner: Runner | None = None,
) -> MrisCurvatureOutputs:
    """
    Compute the second fundamental form of a cortical surface to generate mean and
    Gaussian curvature.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        save_curvature_files: Save curvature files (will only generate screen\
            output without this option).
        max_principal_curvature: Save 1st (max) principal curvature in\
            ?h.<surface>.max file.
        mgh_output_format: Save outputs in .mgz format.
        min_principal_curvature: Save 2nd (min) principal curvature in\
            ?h.<surface>.min file.
        iterative_averages: Perform <avgs> iterative averages of curvature\
            measure before saving.
        neighborhood_size: Set neighborhood size to nbrs.
        random_seed: Set random number generator to seed N.
        curvatures: Stand-alone option to save H (mean), K (gaussian), k1, and\
            k2 curvatures to stem.{curvname}.mgz.
        h_curvature: Stand-alone option to save H mean curvature to stem.H.mgz.
        k_curvature: Stand-alone option to save K gaussian curvature to\
            stem.K.mgz.
        k1_curvature: Stand-alone option to save k1 (primary principle)\
            curvature to stem.k1.mgz.
        k2_curvature: Stand-alone option to save k2 (secondary principle)\
            curvature to stem.k2.mgz.
        k1k2_curvature: Stand-alone option to save k1 and k2 curvature to\
            stem.{k1,k2}.mgz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCurvatureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CURVATURE_METADATA)
    cargs = []
    cargs.append("mris_curvature")
    if save_curvature_files:
        cargs.append("-w")
    if max_principal_curvature:
        cargs.append("-max")
    if mgh_output_format:
        cargs.append("-mgh")
    if min_principal_curvature:
        cargs.append("-min")
    if iterative_averages is not None:
        cargs.extend([
            "-a",
            str(iterative_averages)
        ])
    if neighborhood_size is not None:
        cargs.extend([
            "-nbrs",
            str(neighborhood_size)
        ])
    if random_seed is not None:
        cargs.extend([
            "-seed",
            str(random_seed)
        ])
    if curvatures is not None:
        cargs.extend([
            "-curvs",
            curvatures
        ])
    if h_curvature is not None:
        cargs.extend([
            "-H",
            h_curvature
        ])
    if k_curvature is not None:
        cargs.extend([
            "-K",
            k_curvature
        ])
    if k1_curvature is not None:
        cargs.extend([
            "-k1",
            k1_curvature
        ])
    if k2_curvature is not None:
        cargs.extend([
            "-k2",
            k2_curvature
        ])
    if k1k2_curvature is not None:
        cargs.extend([
            "-k1k2",
            k1k2_curvature
        ])
    cargs.append(execution.input_file(input_surface))
    ret = MrisCurvatureOutputs(
        root=execution.output_file("."),
        mean_curvature=execution.output_file("<hemi>.<surface>.H"),
        gaussian_curvature=execution.output_file("<hemi>.<surface>.K"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CURVATURE_METADATA",
    "MrisCurvatureOutputs",
    "mris_curvature",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAGES_EQUAL_METADATA = Metadata(
    id="830357495ce35a09c03740c89847cea1c8976199.boutiques",
    name="images_equal",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImagesEqualOutputs(typing.NamedTuple):
    """
    Output object returned when calling `images_equal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    comparison_result: OutputPathType
    """Result of the image comparison: 1 if equal, 0 if not."""


def images_equal(
    file_a: InputPathType,
    file_b: InputPathType,
    all_flag: bool = False,
    runner: Runner | None = None,
) -> ImagesEqualOutputs:
    """
    A simple program to test if two 2D images are identical.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        file_a: First image file to compare.
        file_b: Second image file to compare.
        all_flag: Compare all images in the files; all must be equal for exit\
            status to be 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImagesEqualOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGES_EQUAL_METADATA)
    cargs = []
    cargs.append("images_equal")
    cargs.append(execution.input_file(file_a))
    cargs.append(execution.input_file(file_b))
    if all_flag:
        cargs.append("-all")
    ret = ImagesEqualOutputs(
        root=execution.output_file("."),
        comparison_result=execution.output_file("comparison_result.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAGES_EQUAL_METADATA",
    "ImagesEqualOutputs",
    "images_equal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSR_COREG_METADATA = Metadata(
    id="b0e85054bb91348e85b4424dfeba924eb15f6a43.boutiques",
    name="fsr-coreg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsrCoregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsr_coreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_volume: OutputPathType | None
    """Volume produced for each mode in alignment with the reference mode"""
    registration_transform: OutputPathType | None
    """Registration transform file for mode to reference mode"""


def fsr_coreg(
    import_dir: str,
    reference_mode: str,
    num_threads: float | None = None,
    force_update: bool = False,
    output_dir: str | None = None,
    expert_options: InputPathType | None = None,
    runner: Runner | None = None,
) -> FsrCoregOutputs:
    """
    Co-registers input data in preparation for FreeSurfer analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        import_dir: Data directory created by fsr-import.
        reference_mode: Mode to use as a reference (all modes register to this\
            mode).
        num_threads: Number of threads to use.
        force_update: Force update of files regardless of time stamp.
        output_dir: Set the output directory, default is importdir.
        expert_options: Expert options file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsrCoregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSR_COREG_METADATA)
    cargs = []
    cargs.append("fsr-coreg")
    cargs.extend([
        "--i",
        import_dir
    ])
    cargs.extend([
        "--ref",
        reference_mode
    ])
    if num_threads is not None:
        cargs.extend([
            "--threads",
            str(num_threads)
        ])
    if force_update:
        cargs.append("--force-update")
    if output_dir is not None:
        cargs.extend([
            "--o",
            output_dir
        ])
    if expert_options is not None:
        cargs.extend([
            "--expert",
            execution.input_file(expert_options)
        ])
    ret = FsrCoregOutputs(
        root=execution.output_file("."),
        aligned_volume=execution.output_file(output_dir + "/mode.mgz") if (output_dir is not None) else None,
        registration_transform=execution.output_file(output_dir + "/mode.reg-to-ref.lta") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSR_COREG_METADATA",
    "FsrCoregOutputs",
    "fsr_coreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRK_TOOLS_METADATA = Metadata(
    id="4dc371140c0aeb4d9bc3aacbdf63d35a219d2dd8.boutiques",
    name="trk_tools",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TrkToolsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `trk_tools(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    trk_output_file: OutputPathType | None
    """The processed output TRK file"""
    image_output_file: OutputPathType | None
    """Image exported from TRK file"""
    vtk_output_file: OutputPathType | None
    """VTK file containing streamlines"""


def trk_tools(
    reference_image: InputPathType,
    input_trk: InputPathType,
    output_trk: str | None = None,
    output_image: str | None = None,
    update_header: bool = False,
    output_vtk: str | None = None,
    runner: Runner | None = None,
) -> TrkToolsOutputs:
    """
    Tool for processing TRK files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        reference_image: Reference image for TRK processing.
        input_trk: Input TRK file to be processed.
        output_trk: Output TRK file.
        output_image: Export TRK into an image.
        update_header: Update TRK header with reference image.
        output_vtk: Output streamlines in VTK format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TrkToolsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRK_TOOLS_METADATA)
    cargs = []
    cargs.append("trk_tools")
    cargs.extend([
        "-i",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "-f",
        execution.input_file(input_trk)
    ])
    if output_trk is not None:
        cargs.extend([
            "-o",
            output_trk
        ])
    if output_image is not None:
        cargs.extend([
            "-e",
            output_image
        ])
    if update_header:
        cargs.append("-u")
    if output_vtk is not None:
        cargs.extend([
            "-v",
            output_vtk
        ])
    ret = TrkToolsOutputs(
        root=execution.output_file("."),
        trk_output_file=execution.output_file(output_trk) if (output_trk is not None) else None,
        image_output_file=execution.output_file(output_image) if (output_image is not None) else None,
        vtk_output_file=execution.output_file(output_vtk) if (output_vtk is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRK_TOOLS_METADATA",
    "TrkToolsOutputs",
    "trk_tools",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DISTANCE_TRANSFORM_METADATA = Metadata(
    id="7714e4c14a355415364e79e36d2280280f83a066.boutiques",
    name="mri_distance_transform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDistanceTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_distance_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume file after distance transform"""


def mri_distance_transform(
    input_volume: InputPathType,
    label: int,
    max_distance: int,
    output_volume: str,
    mode: int | None = 1,
    runner: Runner | None = None,
) -> MriDistanceTransformOutputs:
    """
    Tool to compute distance transforms on MRI volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        label: Label value for distance transform calculation.
        max_distance: Maximum distance for the transform.
        output_volume: Output volume file.
        mode: Mode of the distance transform: 1 = outside, 2 = inside, 3 =\
            both, 4 = both unsigned.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDistanceTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DISTANCE_TRANSFORM_METADATA)
    cargs = []
    cargs.append("mri_distance_transform")
    cargs.append(execution.input_file(input_volume))
    cargs.append(str(label))
    cargs.append(str(max_distance))
    if mode is not None:
        cargs.append(str(mode))
    cargs.append(output_volume)
    ret = MriDistanceTransformOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DISTANCE_TRANSFORM_METADATA",
    "MriDistanceTransformOutputs",
    "mri_distance_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_WATERSHED_METADATA = Metadata(
    id="9a2bd956b5f350b8c0603b62d7b760dba26dc82d.boutiques",
    name="mris_watershed",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisWatershedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_watershed(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_annotation_file: OutputPathType
    """The resulting annotation file from the watershed transform"""


def mris_watershed(
    input_surface: InputPathType,
    input_gradient_field: InputPathType,
    output_annotation: str,
    max_clusters: float | None = None,
    mask_label: str | None = None,
    runner: Runner | None = None,
) -> MrisWatershedOutputs:
    """
    This program computes the watershed transform on the surface of an intensity
    gradient and writes the resulting measurement into a .annot file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        input_gradient_field: Input gradient field file.
        output_annotation: Output annotation file.
        max_clusters: Set the number of maximum clusters.
        mask_label: Read in and mask the input volume that is not in the\
            specified label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisWatershedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_WATERSHED_METADATA)
    cargs = []
    cargs.append("mris_watershed")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(input_gradient_field))
    cargs.append(output_annotation)
    if max_clusters is not None:
        cargs.extend([
            "-M",
            str(max_clusters)
        ])
    if mask_label is not None:
        cargs.extend([
            "-mask_label",
            mask_label
        ])
    ret = MrisWatershedOutputs(
        root=execution.output_file("."),
        output_annotation_file=execution.output_file(output_annotation),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_WATERSHED_METADATA",
    "MrisWatershedOutputs",
    "mris_watershed",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INVWARP_METADATA = Metadata(
    id="e836370154f7a44a264fcff7fdc45d5150a0c0b2.boutiques",
    name="invwarp",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class InvwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `invwarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inverse_warp: OutputPathType
    """Name of output file, containing warps that are the "reverse" of those in
    --warp. this will be a field-file (rather than a file of spline
    coefficients), and it will have any affine component included as part of the
    displacements."""


def invwarp(
    warp: InputPathType,
    out_img: str,
    ref_img: InputPathType,
    absolute: bool = False,
    relative: bool = False,
    noconstraint: bool = False,
    jacobian_min: float | None = None,
    jacobian_max: float | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> InvwarpOutputs:
    """
    
    Use FSL Invwarp to invert a FNIRT warp.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        warp: Filename for warp/shiftmap transform (volume).
        out_img: Filename for output (inverse warped) image.
        ref_img: Filename for new reference image.
        absolute: Use absolute warp convention (default): x' = w(x).
        relative: Use relative warp convention (default): x' = x + w(x).
        noconstraint: Do not apply jacobian constraint.
        jacobian_min: Minimum acceptable jacobian value for constraint (default\
            0.01).
        jacobian_max: Maximum acceptable jacobian value for constraint (default\
            100.0).
        debug: Turn on debugging output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InvwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INVWARP_METADATA)
    cargs = []
    cargs.append("invwarp")
    cargs.append("--warp=" + execution.input_file(warp))
    cargs.append("--out=" + out_img)
    cargs.append("--ref=" + execution.input_file(ref_img))
    if absolute:
        cargs.append("--abs")
    if relative:
        cargs.append("--rel")
    if noconstraint:
        cargs.append("--noconstraint")
    if jacobian_min is not None:
        cargs.append("--jmin=" + str(jacobian_min))
    if jacobian_max is not None:
        cargs.append("--jmax=" + str(jacobian_max))
    if debug:
        cargs.append("--debug")
    ret = InvwarpOutputs(
        root=execution.output_file("."),
        inverse_warp=execution.output_file(out_img),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INVWARP_METADATA",
    "InvwarpOutputs",
    "invwarp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTSJACOBIAN_METADATA = Metadata(
    id="4c1495ce17166625b172b3fbe727bd30b17f079f.boutiques",
    name="ANTSJacobian",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsjacobianOutputs(typing.NamedTuple):
    """
    Output object returned when calling `antsjacobian(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    jacobian_output: OutputPathType
    """Output file containing the Jacobian determinant information."""


def antsjacobian(
    imagedim: int,
    gwarp: InputPathType,
    outfile: str,
    uselog: int,
    maskfn: InputPathType,
    normbytotalbool: int,
    projectionvector: str | None = None,
    runner: Runner | None = None,
) -> AntsjacobianOutputs:
    """
    Calculate the Jacobian determinant of a transformation using ANTs. WARNING:
    ANTSJacobian may not be working correctly; see CreateJacobianDeterminantImage
    for an alternative method.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        imagedim: The dimensionality of the input image.
        gwarp: The input warp image.
        outfile: The prefix for the output files.
        uselog: Whether to use logarithm in computation.
        maskfn: Mask file used in the computation.
        normbytotalbool: Normalize the Jacobian by the total in the mask. Use\
            this to adjust for head size.
        projectionvector: Projects the warp along the specified direction. Do\
            not add this option if no projection is desired.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsjacobianOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTSJACOBIAN_METADATA)
    cargs = []
    cargs.append("ANTSJacobian")
    cargs.append(str(imagedim))
    cargs.append(execution.input_file(gwarp))
    cargs.append(outfile)
    cargs.append(str(uselog))
    cargs.append(execution.input_file(maskfn))
    cargs.append(str(normbytotalbool))
    if projectionvector is not None:
        cargs.append(projectionvector)
    ret = AntsjacobianOutputs(
        root=execution.output_file("."),
        jacobian_output=execution.output_file(outfile + "Jacobian.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTSJACOBIAN_METADATA",
    "AntsjacobianOutputs",
    "antsjacobian",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REMOVE_INTERSECTION_METADATA = Metadata(
    id="96ab5df1b694c34b019d2062381f43e1e69cf9b2.boutiques",
    name="mris_remove_intersection",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRemoveIntersectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_remove_intersection(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_corrected_surface: OutputPathType
    """Corrected surface output file."""
    out_map_file: OutputPathType | None
    """Binary map of intersections."""


def mris_remove_intersection(
    surface_in_file: InputPathType,
    corrected_surface_out_file: InputPathType,
    fill_holes: bool = False,
    map_option: InputPathType | None = None,
    projdistmm: float | None = None,
    runner: Runner | None = None,
) -> MrisRemoveIntersectionOutputs:
    """
    Tool to remove intersections in surface files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface_in_file: Input surface file.
        corrected_surface_out_file: Corrected output surface file.
        fill_holes: Fill any holes in the intersection mark map and include\
            them in the fix.
        map_option: Create a binary map of intersections.
        projdistmm: Projection distance in mm when using -map option.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRemoveIntersectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REMOVE_INTERSECTION_METADATA)
    cargs = []
    cargs.append("mris_remove_intersection")
    cargs.append(execution.input_file(surface_in_file))
    cargs.append(execution.input_file(corrected_surface_out_file))
    if fill_holes:
        cargs.append("-fill-holes")
    if map_option is not None:
        cargs.extend([
            "-map",
            execution.input_file(map_option)
        ])
    if projdistmm is not None:
        cargs.append(str(projdistmm))
    ret = MrisRemoveIntersectionOutputs(
        root=execution.output_file("."),
        out_corrected_surface=execution.output_file(pathlib.Path(corrected_surface_out_file).name),
        out_map_file=execution.output_file(pathlib.Path(map_option).name) if (map_option is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REMOVE_INTERSECTION_METADATA",
    "MrisRemoveIntersectionOutputs",
    "mris_remove_intersection",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LTA_DIFF_METADATA = Metadata(
    id="e99c49541b6ef2ad5939381bb81d7249502ffc0c.boutiques",
    name="lta_diff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LtaDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `lta_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def lta_diff(
    transform1: InputPathType,
    transform2: InputPathType | None = None,
    dist_type: int | None = None,
    invert1: bool = False,
    invert2: bool = False,
    vox: bool = False,
    normdiv: float | None = None,
    radius: float | None = None,
    runner: Runner | None = None,
) -> LtaDiffOutputs:
    """
    A tool to compute different distance norms for a single transform or for the
    difference between two transforms.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        transform1: First transform file.
        transform2: Second transform file.
        dist_type: Distance type: 1 (Rigid Trans. Dist.), 2 (Affine Transform\
            Distance), 3 (8-corners mean distance), 4 (Max Displacement), 5\
            (Determinant scaling), 6 (Interpolation Smoothing), 7 (Decomposition).\
            Default is 2.
        invert1: Invert first transform before computing difference matrix D.
        invert2: Invert second transform before computing difference matrix D.
        vox: Compute distance in vox coordinates, after adjusting for voxel\
            sizes. Default is RAS coordinates.
        normdiv: Divide final distance by this value for step adjustment.
        radius: Radius in mm, used for RMS distance. Default is 100 to include\
            the head.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LtaDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LTA_DIFF_METADATA)
    cargs = []
    cargs.append("lta_diff")
    cargs.append(execution.input_file(transform1))
    if transform2 is not None:
        cargs.append(execution.input_file(transform2))
    if dist_type is not None:
        cargs.extend([
            "--dist",
            str(dist_type)
        ])
    if invert1:
        cargs.append("--invert1")
    if invert2:
        cargs.append("--invert2")
    if vox:
        cargs.append("--vox")
    if normdiv is not None:
        cargs.extend([
            "--normdiv",
            str(normdiv)
        ])
    if radius is not None:
        cargs.extend([
            "--radius",
            str(radius)
        ])
    ret = LtaDiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LTA_DIFF_METADATA",
    "LtaDiffOutputs",
    "lta_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEDANA_WRAPPER_PY_METADATA = Metadata(
    id="2a5d2d42a60628be534dad0f8a18d103f5db8377.boutiques",
    name="tedana_wrapper.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class TedanaWrapperPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tedana_wrapper_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tedana_output: OutputPathType | None
    """Output directory for tedana results."""
    tedana_report: OutputPathType | None
    """Tedana report file."""


def tedana_wrapper_py(
    input_files: list[InputPathType],
    echo_times: list[float],
    mask: InputPathType,
    results_dir: str | None = None,
    prefix: str | None = None,
    save_all: bool = False,
    prep_only: bool = False,
    tedana_prog: str | None = None,
    tedana_is_exec: bool = False,
    ted_label: str | None = None,
    tedana_opts: str | None = None,
    runner: Runner | None = None,
) -> TedanaWrapperPyOutputs:
    """
    Internal wrapper to run tedana.py, typically used within afni_proc.py.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: 4D dataset for each echo.
        echo_times: Echo time (ms) for each echo.
        mask: Mask in same space/grid as the input datasets.
        results_dir: Folder to be created for all outputs. Default\
            [./Bunnymen].
        prefix: Prefix for dataset names. Default [Bunnymen].
        save_all: Save intermediate datasets. Default is to save only the\
            3dZcat stacked dataset (and tedana stuff).
        prep_only: Do not run tedana.py, stop at 3dZcat.
        tedana_prog: Path and name of the version of tedana.py that will be\
            run. Default is meica.libs/tedana.py in the afni binaries directory.
        tedana_is_exec: Run 'tedana.py' rather than 'python tedana.py'.
        ted_label: Suffix for output folder. Adds suffix like TED.LABEL (NOT A\
            PATH).
        tedana_opts: Additional options to pass to tedana.py. (In quotes)\
            Example: '--initcost=tanh --conv=2.5e-5'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TedanaWrapperPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEDANA_WRAPPER_PY_METADATA)
    cargs = []
    cargs.append("tedana_wrapper.py")
    cargs.extend([
        "-input",
        *[execution.input_file(f) for f in input_files]
    ])
    cargs.extend([
        "-TE",
        *map(str, echo_times)
    ])
    cargs.extend([
        "-mask",
        execution.input_file(mask)
    ])
    if results_dir is not None:
        cargs.extend([
            "-results_dir",
            results_dir
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if save_all:
        cargs.append("-save_all")
    if prep_only:
        cargs.append("-prep_only")
    if tedana_prog is not None:
        cargs.extend([
            "-tedana_prog",
            tedana_prog
        ])
    if tedana_is_exec:
        cargs.append("-tedana_is_exec")
    if ted_label is not None:
        cargs.extend([
            "-ted_label",
            ted_label
        ])
    if tedana_opts is not None:
        cargs.extend([
            "-tedana_opts",
            tedana_opts
        ])
    ret = TedanaWrapperPyOutputs(
        root=execution.output_file("."),
        tedana_output=execution.output_file(results_dir + "/" + prefix + "_ted_output") if (results_dir is not None and prefix is not None) else None,
        tedana_report=execution.output_file(results_dir + "/" + prefix + "_tedana_report.txt") if (results_dir is not None and prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEDANA_WRAPPER_PY_METADATA",
    "TedanaWrapperPyOutputs",
    "tedana_wrapper_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOL2SUBFIELD_METADATA = Metadata(
    id="ec503af3368509aa5b191ee5f77a6d7c5a57bc38.boutiques",
    name="vol2subfield",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Vol2subfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vol2subfield(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mapped_output_volume: OutputPathType | None
    """Output volume mapped into subfield volume space"""
    output_registration_file: OutputPathType | None
    """Output registration file"""
    segmentation_stats_file: OutputPathType | None
    """Statistics output file generated by mri_segstats"""
    average_waveform_file: OutputPathType | None
    """Average waveform output file"""
    average_waveform_volume_file: OutputPathType | None
    """Average waveform volume output file"""


def vol2subfield(
    input_volume: InputPathType,
    subfield_volume: InputPathType,
    registration_file: InputPathType,
    output_volume: str | None = None,
    output_registration: str | None = None,
    stats_output: str | None = None,
    avgwf_output: str | None = None,
    avgwfvol_output: str | None = None,
    color_table: InputPathType | None = None,
    interpolation_cubic: bool = False,
    tmp_directory: str | None = None,
    preset_subfield_brainstem: bool = False,
    runner: Runner | None = None,
) -> Vol2subfieldOutputs:
    """
    A tool for integrating arbitrary volumes with volumes that share a RAS space
    with the orig volume in the FreeSurfer mri folder.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        subfield_volume: Subfield volume (full path or relative to subject/mri).
        registration_file: Registration that maps input volume to conformed\
            space.
        output_volume: Output volume.
        output_registration: Registration between input volume and subfield.
        stats_output: Run mri_segstats with --sum output to this file.
        avgwf_output: Run mri_segstats with --avgwf output to this file.
        avgwfvol_output: Run mri_segstats with --avgwfvol output to this file.
        color_table: Color table to use with mri_segstats.
        interpolation_cubic: Use cubic interpolation.
        tmp_directory: Temporary directory for debugging.
        preset_subfield_brainstem: Set subfield to brainstemSsLabels.v12.mgz.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Vol2subfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOL2SUBFIELD_METADATA)
    cargs = []
    cargs.append("vol2subfield")
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--sf",
        execution.input_file(subfield_volume)
    ])
    cargs.extend([
        "--reg",
        execution.input_file(registration_file)
    ])
    if output_volume is not None:
        cargs.extend([
            "--o",
            output_volume
        ])
    if output_registration is not None:
        cargs.extend([
            "--outreg",
            output_registration
        ])
    if stats_output is not None:
        cargs.extend([
            "--stats",
            stats_output
        ])
    if avgwf_output is not None:
        cargs.extend([
            "--avgwf",
            avgwf_output
        ])
    if avgwfvol_output is not None:
        cargs.extend([
            "--avgwfvol",
            avgwfvol_output
        ])
    if color_table is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(color_table)
        ])
    if interpolation_cubic:
        cargs.append("--cubic")
    if tmp_directory is not None:
        cargs.extend([
            "--tmp",
            tmp_directory
        ])
    if preset_subfield_brainstem:
        cargs.append("--brainstem")
    ret = Vol2subfieldOutputs(
        root=execution.output_file("."),
        mapped_output_volume=execution.output_file(output_volume) if (output_volume is not None) else None,
        output_registration_file=execution.output_file(output_registration) if (output_registration is not None) else None,
        segmentation_stats_file=execution.output_file(stats_output) if (stats_output is not None) else None,
        average_waveform_file=execution.output_file(avgwf_output) if (avgwf_output is not None) else None,
        average_waveform_volume_file=execution.output_file(avgwfvol_output) if (avgwfvol_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOL2SUBFIELD_METADATA",
    "Vol2subfieldOutputs",
    "vol2subfield",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_DIMS_METADATA = Metadata(
    id="eeaee23c17f988ab29947856353b846c3907f154.boutiques",
    name="@GetAfniDims",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniDimsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_dims(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dims_output: OutputPathType
    """Text file containing the dimensions of the input dataset"""


def v__get_afni_dims(
    input_dset: InputPathType,
    runner: Runner | None = None,
) -> VGetAfniDimsOutputs:
    """
    A utility tool to return dimensions of AFNI dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dset: Input AFNI dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniDimsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_DIMS_METADATA)
    cargs = []
    cargs.append("@GetAfniDims")
    cargs.append(execution.input_file(input_dset))
    ret = VGetAfniDimsOutputs(
        root=execution.output_file("."),
        dims_output=execution.output_file("dims_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniDimsOutputs",
    "V__GET_AFNI_DIMS_METADATA",
    "v__get_afni_dims",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_MODIFY_SPHERE_METADATA = Metadata(
    id="7ba7bdfa9f75a3f280b0446651d5074e673b22aa.boutiques",
    name="surface-modify-sphere",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceModifySphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_modify_sphere(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sphere_out: OutputPathType
    """the output sphere"""


def surface_modify_sphere(
    sphere_in: InputPathType,
    radius: float,
    sphere_out: str,
    opt_recenter: bool = False,
    runner: Runner | None = None,
) -> SurfaceModifySphereOutputs:
    """
    Change radius and optionally recenter a sphere.
    
    This command may be useful if you have used -surface-resample to resample a
    sphere, which can suffer from problems generally not present in
    -surface-sphere-project-unproject. If the sphere should already be centered
    around the origin, using -recenter may still shift it slightly before
    changing the radius, which is likely to be undesireable.
    
    If <sphere-in> is not close to spherical, or not centered around the origin
    and -recenter is not used, a warning is printed.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        sphere_in: the sphere to modify.
        radius: the radius the output sphere should have.
        sphere_out: the output sphere.
        opt_recenter: recenter the sphere by means of the bounding box.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceModifySphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_MODIFY_SPHERE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-modify-sphere")
    cargs.append(execution.input_file(sphere_in))
    cargs.append(str(radius))
    cargs.append(sphere_out)
    if opt_recenter:
        cargs.append("-recenter")
    ret = SurfaceModifySphereOutputs(
        root=execution.output_file("."),
        sphere_out=execution.output_file(sphere_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_MODIFY_SPHERE_METADATA",
    "SurfaceModifySphereOutputs",
    "surface_modify_sphere",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INVFEATREG_METADATA = Metadata(
    id="dfd93a0e3c77ac7d8350f0e55ba782b5705b1969.boutiques",
    name="invfeatreg",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class InvfeatregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `invfeatreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def invfeatreg(
    feat_directory: str,
    runner: Runner | None = None,
) -> InvfeatregOutputs:
    """
    Inverse warp image using FNIRT.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        feat_directory: FEAT Directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InvfeatregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INVFEATREG_METADATA)
    cargs = []
    cargs.append("invfeatreg")
    cargs.append(feat_directory)
    ret = InvfeatregOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INVFEATREG_METADATA",
    "InvfeatregOutputs",
    "invfeatreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSPYTHON_METADATA = Metadata(
    id="2424f19a382cf96fd7771ce3d7180d81a8324105.boutiques",
    name="fspython",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FspythonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fspython(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fspython(
    args: list[str] | None = None,
    runner: Runner | None = None,
) -> FspythonOutputs:
    """
    Freesurfer's embedded Python interpreter.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Arguments passed to the program.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FspythonOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSPYTHON_METADATA)
    cargs = []
    cargs.append("python3")
    cargs.append("[OPTION]")
    if args is not None:
        cargs.extend(args)
    ret = FspythonOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSPYTHON_METADATA",
    "FspythonOutputs",
    "fspython",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CONVERT_METADATA = Metadata(
    id="2935cffb17b5edbbc239ffbc0efa59b1c070ffca.boutiques",
    name="mris_convert",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_convert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_surface: OutputPathType
    """Output converted surface file"""


def mris_convert(
    input_file: InputPathType,
    output_file: str,
    second_input_file: InputPathType | None = None,
    patch: bool = False,
    curv_overlay_files: list[str] | None = None,
    functional_data_file: InputPathType | None = None,
    orig_positions: str | None = None,
    scale: float | None = None,
    rescale: bool = False,
    talairach_xfm: str | None = None,
    normals: bool = False,
    neighbors: bool = False,
    xyz: bool = False,
    annotation_file: InputPathType | None = None,
    parcstats_file: InputPathType | None = None,
    gifti_dataarray_num: float | None = None,
    label_file: InputPathType | None = None,
    label_stats_file: str | None = None,
    combine_surfs: bool = False,
    merge_gifti: bool = False,
    split_gifti: bool = False,
    gifti_outdir: str | None = None,
    delete_cmds: bool = False,
    center: bool = False,
    vol_geom: str | None = None,
    remove_vol_geom: bool = False,
    to_surf: str | None = None,
    to_scanner: bool = False,
    to_tkr: bool = False,
    userealras: bool = False,
    usesurfras: bool = False,
    upsample: str | None = None,
    volume: str | None = None,
    area: str | None = None,
    angle: str | None = None,
    label_to_mask: str | None = None,
    cras_add: bool = False,
    cras_subtract: bool = False,
    runner: Runner | None = None,
) -> MrisConvertOutputs:
    """
    This program will convert MRI-surface data formats.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input filename.
        output_file: Output filename.
        second_input_file: Second input filename to be combined, required for\
            --combinesurfs.
        patch: Input file is a patch file, not a full surface.
        curv_overlay_files: Input scalar curv overlay files.
        functional_data_file: Input functional time-series or other multi-frame\
            data.
        orig_positions: Read orig positions.
        scale: Scale vertex xyz by scale.
        rescale: Rescale vertex xyz so total area is same as group average.
        talairach_xfm: Apply talairach xfm of subject to vertex xyz.
        normals: Output ascii file where vertex data is the surface normal\
            vector.
        neighbors: Write out neighbors of a vertex in each row.
        xyz: Print only surface xyz to ascii file.
        annotation_file: Input annotation or gifti label data.
        parcstats_file: Input text file containing label/val pairs for\
            parcellation.
        gifti_dataarray_num: Input gifti dataarray number to use.
        label_file: Input .label file and name for this label.
        label_stats_file: Output gifti file to which label stats will be\
            written.
        combine_surfs: Combine surface files, two input surface files required.
        merge_gifti: Generate combined gifti file with surface and multiple\
            curvature data.
        split_gifti: Separate surface and data array from combined gifti file.
        gifti_outdir: Output directory for generated gifti files.
        delete_cmds: Delete command lines in surface.
        center: Put center of surface at (0,0,0).
        vol_geom: Use MRIVol to set the volume geometry.
        remove_vol_geom: Set the valid flag in vg to 0.
        to_surf: Copy coordinates from surfcoords to output (good for patches).
        to_scanner: Convert coordinates from native FS (tkr) coords to scanner\
            coords.
        to_tkr: Convert coordinates from scanner coords to native FS (tkr)\
            coords.
        userealras: Same as --to-scanner.
        usesurfras: Same as --to-tkr.
        upsample: Upsample N times by splitting edges/faces.
        volume: Compute vertex-wise volume.
        area: Compute vertex-wise area.
        angle: Compute cortical orientation angles.
        label_to_mask: Convert a surface-based label to a binary mask.
        cras_add: Shift center to scanner coordinate center.
        cras_subtract: Shift center from scanner coordinate center.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CONVERT_METADATA)
    cargs = []
    cargs.append("mris_convert")
    cargs.append(execution.input_file(input_file))
    if second_input_file is not None:
        cargs.append(execution.input_file(second_input_file))
    cargs.append(output_file)
    if patch:
        cargs.append("-p")
    if curv_overlay_files is not None:
        cargs.extend([
            "-c",
            *curv_overlay_files
        ])
    if functional_data_file is not None:
        cargs.extend([
            "-f",
            execution.input_file(functional_data_file)
        ])
    if orig_positions is not None:
        cargs.extend([
            "-o",
            orig_positions
        ])
    if scale is not None:
        cargs.extend([
            "-s",
            str(scale)
        ])
    if rescale:
        cargs.append("-r")
    if talairach_xfm is not None:
        cargs.extend([
            "-t",
            talairach_xfm
        ])
    if normals:
        cargs.append("-n")
    if neighbors:
        cargs.append("-v")
    if xyz:
        cargs.append("-a")
    if annotation_file is not None:
        cargs.extend([
            "--annot",
            execution.input_file(annotation_file)
        ])
    if parcstats_file is not None:
        cargs.extend([
            "--parcstats",
            execution.input_file(parcstats_file)
        ])
    if gifti_dataarray_num is not None:
        cargs.extend([
            "--da_num",
            str(gifti_dataarray_num)
        ])
    if label_file is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_file)
        ])
    if label_stats_file is not None:
        cargs.extend([
            "--labelstats",
            label_stats_file
        ])
    if combine_surfs:
        cargs.append("--combinesurfs")
    if merge_gifti:
        cargs.append("--mergegifti")
    if split_gifti:
        cargs.append("--splitgifti")
    if gifti_outdir is not None:
        cargs.extend([
            "--giftioutdir",
            gifti_outdir
        ])
    if delete_cmds:
        cargs.append("--delete-cmds")
    if center:
        cargs.append("--center")
    if vol_geom is not None:
        cargs.extend([
            "--vol-geom",
            vol_geom
        ])
    if remove_vol_geom:
        cargs.append("--remove-vol-geom")
    if to_surf is not None:
        cargs.extend([
            "--to-surf",
            to_surf
        ])
    if to_scanner:
        cargs.append("--to-scanner")
    if to_tkr:
        cargs.append("--to-tkr")
    if userealras:
        cargs.append("--userealras")
    if usesurfras:
        cargs.append("--usesurfras")
    if upsample is not None:
        cargs.extend([
            "--upsample",
            upsample
        ])
    if volume is not None:
        cargs.extend([
            "--volume",
            volume
        ])
    if area is not None:
        cargs.extend([
            "--area",
            area
        ])
    if angle is not None:
        cargs.extend([
            "--angle",
            angle
        ])
    if label_to_mask is not None:
        cargs.extend([
            "--label2mask",
            label_to_mask
        ])
    if cras_add:
        cargs.append("--cras_add")
    if cras_subtract:
        cargs.append("--cras_subtract")
    ret = MrisConvertOutputs(
        root=execution.output_file("."),
        converted_surface=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CONVERT_METADATA",
    "MrisConvertOutputs",
    "mris_convert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGMENT_THALAMIC_NUCLEI_DTI_CNN_METADATA = Metadata(
    id="0d6b3980cf69cb76b17660e3b5ddbf899684c85e.boutiques",
    name="mri_segment_thalamic_nuclei_dti_cnn",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegmentThalamicNucleiDtiCnnOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_segment_thalamic_nuclei_dti_cnn(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """Path to the segmentation output."""
    volume_csv: OutputPathType | None
    """CSV file with volumes for all structures."""
    posteriors: OutputPathType | None
    """Path to the posteriors output."""


def mri_segment_thalamic_nuclei_dti_cnn(
    t1_images: InputPathType,
    fa: InputPathType,
    v1: InputPathType,
    output: InputPathType,
    aseg: InputPathType | None = None,
    volume_output: InputPathType | None = None,
    posteriors_output: InputPathType | None = None,
    threads: float | None = None,
    force_cpu: bool = False,
    model: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriSegmentThalamicNucleiDtiCnnOutputs:
    """
    Thalamic segmentation tool providing 0.7mm isotropic thalamus segmentation from
    registered T1, FA, and V1 volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_images: Path to the T1 image(s) or folder containing images. These\
            must be registered to the FAs in physical coordinates.
        fa: Path to the FA image(s) or folder.
        v1: Path to the V1 image(s) or folder.
        output: Path to the segmentation output(s) or folder.
        aseg: Path to the ASEG segmentation(s) or folder. These must be\
            registered to the FAs in physical coordinates.
        volume_output: CSV file for volumes of all structures and subjects.
        posteriors_output: Path to the posteriors output(s) or folder.
        threads: Number of cores to be used. Default is 1.
        force_cpu: Enforce running with CPU rather than GPU.
        model: Path to an alternative model file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegmentThalamicNucleiDtiCnnOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGMENT_THALAMIC_NUCLEI_DTI_CNN_METADATA)
    cargs = []
    cargs.append("mri_segment_thalamic_nuclei_dti_cnn")
    cargs.extend([
        "--t1",
        execution.input_file(t1_images)
    ])
    if aseg is not None:
        cargs.extend([
            "--aseg",
            execution.input_file(aseg)
        ])
    cargs.extend([
        "--fa",
        execution.input_file(fa)
    ])
    cargs.extend([
        "--v1",
        execution.input_file(v1)
    ])
    cargs.extend([
        "--o",
        execution.input_file(output)
    ])
    if volume_output is not None:
        cargs.extend([
            "--vol",
            execution.input_file(volume_output)
        ])
    if posteriors_output is not None:
        cargs.extend([
            "--post",
            execution.input_file(posteriors_output)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if force_cpu:
        cargs.append("--cpu")
    if model is not None:
        cargs.extend([
            "--model",
            execution.input_file(model)
        ])
    ret = MriSegmentThalamicNucleiDtiCnnOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(pathlib.Path(output).name),
        volume_csv=execution.output_file(pathlib.Path(volume_output).name) if (volume_output is not None) else None,
        posteriors=execution.output_file(pathlib.Path(posteriors_output).name) if (posteriors_output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGMENT_THALAMIC_NUCLEI_DTI_CNN_METADATA",
    "MriSegmentThalamicNucleiDtiCnnOutputs",
    "mri_segment_thalamic_nuclei_dti_cnn",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DPLOT_PY_METADATA = Metadata(
    id="9a09a3b646afa4ae694c267932f8acdb6bcb6eec.boutiques",
    name="1dplot.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dplotPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dplot_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Output image file, default to .jpg"""


def v_1dplot_py(
    infiles: list[InputPathType],
    prefix: str,
    help_: bool = False,
    boxplot_on: bool = False,
    bplot_view: str | None = None,
    margin_off: bool = False,
    scale: list[str] | None = None,
    xfile: InputPathType | None = None,
    xvals: list[float] | None = None,
    yaxis: list[str] | None = None,
    ylabels: list[str] | None = None,
    ylabels_maxlen: float | None = None,
    legend_on: bool = False,
    legend_labels: list[str] | None = None,
    legend_locs: list[str] | None = None,
    xlabel: str | None = None,
    title: str | None = None,
    reverse_order: bool = False,
    sepscl: bool = False,
    one_graph: bool = False,
    dpi: float | None = None,
    figsize: list[float] | None = None,
    fontsize: float | None = None,
    fontfamily: str | None = None,
    fontstyles: str | None = None,
    colors: list[str] | None = None,
    patches: list[str] | None = None,
    censor_trs: list[str] | None = None,
    censor_files: list[InputPathType] | None = None,
    censor_hline: list[str] | None = None,
    censor_rgb: str | None = None,
    bkgd_color: str | None = None,
    runner: Runner | None = None,
) -> V1dplotPyOutputs:
    """
    This program is for making images to visualize columns of numbers from 1D text
    files. It uses Python, particularly matplotlib, to create plots.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infiles: One or more file names of text files. Each column in this file\
            will be treated as a separate time series for plotting.
        prefix: Output filename or prefix. Default output image type is .jpg.
        help_: See helpfile.
        boxplot_on: A fun feature to show an additional boxplot adjacent to\
            each time series.
        bplot_view: Adjust view for boxplots when using censoring.
        margin_off: Fill the plot frame completely, thus no labels, frame, or\
            titles will be visible.
        scale: Provide a list of scales to apply to the y-values.
        xfile: One way to input x-values explicitly: as a "1D" file containing\
            a single file of numbers.
        xvals: Provide exactly 3 numbers for x-values: start, stop, and\
            stepsize.
        yaxis: Optional range for each 'infile' y-axis.
        ylabels: Optional text labels for each 'infile' column.
        ylabels_maxlen: allows y-axis labels to wrap into multiple rows, each\
            of length <= which the user can decide.
        legend_on: Turn on the plotting of a legend in the plot(s).
        legend_labels: Optional legend labels, if using '-legend_on'.
        legend_locs: Optional legend locations, if using '-legend_on'.
        xlabel: Optional text labels for the abscissa/x-axis.
        title: Optional title for the set of plots.
        reverse_order: Reverses the order of plotted time series.
        sepscl: Make each graph have its own y-range.
        one_graph: Plot multiple infiles in a single subplot.
        dpi: Choose the output image's DPI. Default value is 150.
        figsize: Choose the output image's dimensions (units are inches).
        fontsize: Change image fontsize; default is 10.
        fontfamily: Change font-family used; default is monospace.
        fontstyles: Add a specific font name; should match with chosen\
            font-family.
        colors: Decide what color(s) to cycle through in plots (one or more).
        patches: Specify run lengths for background patches to distinguish runs.
        censor_trs: Specify time points where censoring has occurred using AFNI\
            index notation.
        censor_files: Specify time points where censoring has occurred using\
            one or more 1D files.
        censor_hline: Add a dotted horizontal line to the plot, representing\
            the censor threshold.
        censor_rgb: Choose the color of the censoring background; default is:\
            [1, 0.7, 0.7].
        bkgd_color: Change the background color outside of the plot windows.\
            Default is 0.9.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dplotPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DPLOT_PY_METADATA)
    cargs = []
    cargs.append("1dplot.py")
    cargs.extend([
        "-infiles",
        *[execution.input_file(f) for f in infiles]
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if help_:
        cargs.append("-h")
    if boxplot_on:
        cargs.append("-boxplot_on")
    if bplot_view is not None:
        cargs.extend([
            "-bplot_view",
            bplot_view
        ])
    if margin_off:
        cargs.append("-margin_off")
    if scale is not None:
        cargs.extend([
            "-scale",
            *scale
        ])
    if xfile is not None:
        cargs.extend([
            "-xfile",
            execution.input_file(xfile)
        ])
    if xvals is not None:
        cargs.extend([
            "-xvals",
            *map(str, xvals)
        ])
    if yaxis is not None:
        cargs.extend([
            "-yaxis",
            *yaxis
        ])
    if ylabels is not None:
        cargs.extend([
            "-ylabels",
            *ylabels
        ])
    if ylabels_maxlen is not None:
        cargs.extend([
            "-ylabels_maxlen",
            str(ylabels_maxlen)
        ])
    if legend_on:
        cargs.append("-legend_on")
    if legend_labels is not None:
        cargs.extend([
            "-legend_labels",
            *legend_labels
        ])
    if legend_locs is not None:
        cargs.extend([
            "-legend_locs",
            *legend_locs
        ])
    if xlabel is not None:
        cargs.extend([
            "-xlabel",
            xlabel
        ])
    if title is not None:
        cargs.extend([
            "-title",
            title
        ])
    if reverse_order:
        cargs.append("-reverse_order")
    if sepscl:
        cargs.append("-sepscl")
    if one_graph:
        cargs.append("-one_graph")
    if dpi is not None:
        cargs.extend([
            "-dpi",
            str(dpi)
        ])
    if figsize is not None:
        cargs.extend([
            "-figsize",
            *map(str, figsize)
        ])
    if fontsize is not None:
        cargs.extend([
            "-fontsize",
            str(fontsize)
        ])
    if fontfamily is not None:
        cargs.extend([
            "-fontfamily",
            fontfamily
        ])
    if fontstyles is not None:
        cargs.extend([
            "-fontstyles",
            fontstyles
        ])
    if colors is not None:
        cargs.extend([
            "-colors",
            *colors
        ])
    if patches is not None:
        cargs.extend([
            "-patches",
            *patches
        ])
    if censor_trs is not None:
        cargs.extend([
            "-censor_trs",
            *censor_trs
        ])
    if censor_files is not None:
        cargs.extend([
            "-censor_files",
            *[execution.input_file(f) for f in censor_files]
        ])
    if censor_hline is not None:
        cargs.extend([
            "-censor_hline",
            *censor_hline
        ])
    if censor_rgb is not None:
        cargs.extend([
            "-censor_RGB",
            censor_rgb
        ])
    if bkgd_color is not None:
        cargs.extend([
            "-bkgd_color",
            bkgd_color
        ])
    ret = V1dplotPyOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(prefix + ".jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dplotPyOutputs",
    "V_1DPLOT_PY_METADATA",
    "v_1dplot_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__TO_RAI_METADATA = Metadata(
    id="ae5bb83cce00bf51d61da1e1b21d495548f69a92.boutiques",
    name="@ToRAI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VToRaiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__to_rai(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__to_rai(
    runner: Runner | None = None,
) -> VToRaiOutputs:
    """
    Tool to change the ORIENT coordinates to RAI.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VToRaiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__TO_RAI_METADATA)
    cargs = []
    cargs.append("@ToRAI")
    cargs.append("<-xyz")
    cargs.append("X")
    cargs.append("Y")
    cargs.append("Z>")
    cargs.append("<-or")
    cargs.append("ORIENT>")
    ret = VToRaiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VToRaiOutputs",
    "V__TO_RAI_METADATA",
    "v__to_rai",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_MARRY_METADATA = Metadata(
    id="bf4086d827742de99647b8c529893b01461d76ef.boutiques",
    name="1dMarry",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dMarryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_marry(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file when marrying files. This file should be captured using a
    redirection such as '>'."""
    divorcee_a: OutputPathType
    """First output file when divorcing."""
    divorcee_b: OutputPathType
    """Second output file when divorcing."""


def v_1d_marry(
    files: list[InputPathType],
    sep: str | None = None,
    divorce: bool = False,
    runner: Runner | None = None,
) -> V1dMarryOutputs:
    """
    Joins together 2 (or more) ragged-right .1D files, for use with 3dDeconvolve
    -stim_times_AM2, or breaks up 1 married file into 2 (or more) single-valued
    files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: Input file(s) to be married or divorced.
        sep: Separator(s) for marrying files. The first character is used as\
            the separator between values 1 and 2, the second character between\
            values 2 and 3, etc.
        divorce: Divorce mode: splits married file into separate files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dMarryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_MARRY_METADATA)
    cargs = []
    cargs.append("1dMarry")
    if sep is not None:
        cargs.extend([
            "-sep",
            sep
        ])
    if divorce:
        cargs.append("-divorce")
    cargs.extend([execution.input_file(f) for f in files])
    cargs.append("[FILE2]")
    ret = V1dMarryOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("stdout"),
        divorcee_a=execution.output_file("[FILE2]_A.1D"),
        divorcee_b=execution.output_file("[FILE2]_B.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dMarryOutputs",
    "V_1D_MARRY_METADATA",
    "v_1d_marry",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STEM2FNAME_METADATA = Metadata(
    id="b941ff1daaefec18565e73dea38778f44521acf7.boutiques",
    name="stem2fname",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Stem2fnameOutputs(typing.NamedTuple):
    """
    Output object returned when calling `stem2fname(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Full filename with the detected format. Format could be one of mgh, mgz,
    nii, nii.gz, bhdr, img, or w."""


def stem2fname(
    stem: str,
    runner: Runner | None = None,
) -> Stem2fnameOutputs:
    """
    Determines the full filename with extension for a given file stem by checking
    various formats.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        stem: The stem of the file (without extension).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Stem2fnameOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STEM2FNAME_METADATA)
    cargs = []
    cargs.append("stem2fname")
    cargs.append(stem)
    ret = Stem2fnameOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(stem + ".[FORMAT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STEM2FNAME_METADATA",
    "Stem2fnameOutputs",
    "stem2fname",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SURF2SURF_METADATA = Metadata(
    id="d67a0abaca8f23d784a32410fdaa560c5667746c.boutiques",
    name="mri_surf2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSurf2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_surf2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_values: OutputPathType | None
    """File in which to store output values."""
    trg_distances: OutputPathType | None
    """File containing distances from source to target vertices."""


def mri_surf2surf(
    src_subject: str,
    trg_subject: str,
    sval_path: InputPathType | None = None,
    sval_xyz: str | None = None,
    projfrac: list[str] | None = None,
    projabs: list[str] | None = None,
    sval_tal_xyz: str | None = None,
    sval_area: str | None = None,
    sval_annot: InputPathType | None = None,
    sval_nxyz: str | None = None,
    patch: list[str] | None = None,
    sfmt: str | None = None,
    reg: list[str] | None = None,
    reg_inv: list[str] | None = None,
    srcicoorder: int | None = None,
    trgicoorder: int | None = None,
    tval_path: str | None = None,
    tval_xyz: str | None = None,
    tfmt: str | None = None,
    trg_dist: str | None = None,
    s: str | None = None,
    hemi: str | None = None,
    src_hemi: str | None = None,
    trg_hemi: str | None = None,
    dual_hemi: bool = False,
    jac: bool = False,
    surfreg: str | None = None,
    src_surfreg: str | None = None,
    trg_surfreg: str | None = None,
    mapmethod: str | None = None,
    frame: int | None = None,
    fwhm_src: float | None = None,
    fwhm_trg: float | None = None,
    nsmooth_in: int | None = None,
    nsmooth_out: int | None = None,
    cortex: bool = False,
    no_cortex: bool = False,
    label_src: InputPathType | None = None,
    label_trg: InputPathType | None = None,
    mul: float | None = None,
    div: float | None = None,
    reshape: bool = False,
    reshape_factor: int | None = None,
    reshape3d: bool = False,
    split: bool = False,
    synth: bool = False,
    ones: bool = False,
    normvar: bool = False,
    seed: int | None = None,
    prune: bool = False,
    no_prune: bool = False,
    proj_surf: list[str] | None = None,
    proj_norm: list[str] | None = None,
    reg_diff: str | None = None,
    rms: InputPathType | None = None,
    rms_mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriSurf2surfOutputs:
    """
    Resample one surface onto another using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_subject: Name of source subject as found in $SUBJECTS_DIR or ico\
            for icosahedron.
        trg_subject: Name of target subject as found in $SUBJECTS_DIR or ico\
            for icosahedron.
        sval_path: Path of the file with input values.
        sval_xyz: Use xyz of a surface as input.
        projfrac: Use projected xyz of a surface as input.
        projabs: Use projected xyz absolute of a surface as input.
        sval_tal_xyz: Use tal xyz of a surface as input.
        sval_area: Use vertex area of a surface as input.
        sval_annot: Map annotation file.
        sval_nxyz: Use surface normals of a surface as input.
        patch: Specify source patch file, target surface and number of\
            dilations.
        sfmt: Source format type string.
        reg: Apply registration file to sval-xyz.
        reg_inv: Apply inverse registration file to sval-xyz.
        srcicoorder: Icosahedron order for the source.
        trgicoorder: Icosahedron order for the target.
        tval_path: Path of the file in which to store output values.
        tval_xyz: Save target value as a surface file with source xyz.
        tfmt: Target format type string.
        trg_dist: Save distance from source to target vertices.
        s: Use the same subject for both source and target.
        hemi: Hemisphere for both source and target (lh or rh).
        src_hemi: Hemisphere for source (lh or rh).
        trg_hemi: Hemisphere for target (lh or rh).
        dual_hemi: Assume source ?h.?h.surfreg file name.
        jac: Turn on jacobian correction, needed when applying to area or\
            volume.
        surfreg: Surface registration for source and target (sphere.reg).
        src_surfreg: Source surface registration (sphere.reg).
        trg_surfreg: Target surface registration (sphere.reg).
        mapmethod: Method used to map from the vertices in one subject to\
            another (nnfr or nnf).
        frame: Save only nth frame (when using paint output format).
        fwhm_src: Smooth the source to given FWHM.
        fwhm_trg: Smooth the target to given FWHM.
        nsmooth_in: Number of smoothing iterations for input.
        nsmooth_out: Number of smoothing iterations for output.
        cortex: Use ?h.cortex.label as a smoothing mask.
        no_cortex: Do NOT use ?h.cortex.label as a smoothing mask (default).
        label_src: Source smoothing mask.
        label_trg: Target smoothing mask.
        mul: Multiply the input by the given value.
        div: Divide the input by the given value.
        reshape: Reshape output to multiple 'slices'.
        reshape_factor: Reshape to Nfactor 'slices'.
        reshape3d: Reshape fsaverage (ico7) into 42 x 47 x 83.
        split: Output each frame separately.
        synth: Replace input with white Gaussian noise.
        ones: Replace input with 1s.
        normvar: Rescale so that stddev=1 (good with --synth).
        seed: Seed for synth (default is auto).
        prune: Remove any voxel that is zero in any time point (for smoothing).
        no_prune: Do not prune (default).
        proj_surf: Project vertices by mag*scale at each vertex.
        proj_norm: Project vertices by distmm at each vertex.
        reg_diff: Subtract reg2 from --reg (primarily for testing).
        rms: Save RMS of reg1-reg2 (primarily for testing).
        rms_mask: Compute RMS in mask (primarily for testing).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSurf2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SURF2SURF_METADATA)
    cargs = []
    cargs.append("mri_surf2surf")
    cargs.extend([
        "--srcsubject",
        src_subject
    ])
    if sval_path is not None:
        cargs.extend([
            "--sval",
            execution.input_file(sval_path)
        ])
    if sval_xyz is not None:
        cargs.extend([
            "--sval-xyz",
            sval_xyz
        ])
    if projfrac is not None:
        cargs.extend([
            "--projfrac",
            *projfrac
        ])
    if projabs is not None:
        cargs.extend([
            "--projabs",
            *projabs
        ])
    if sval_tal_xyz is not None:
        cargs.extend([
            "--sval-tal-xyz",
            sval_tal_xyz
        ])
    if sval_area is not None:
        cargs.extend([
            "--sval-area",
            sval_area
        ])
    if sval_annot is not None:
        cargs.extend([
            "--sval-annot",
            execution.input_file(sval_annot)
        ])
    if sval_nxyz is not None:
        cargs.extend([
            "--sval-nxyz",
            sval_nxyz
        ])
    if patch is not None:
        cargs.extend([
            "--patch",
            *patch
        ])
    if sfmt is not None:
        cargs.extend([
            "--sfmt",
            sfmt
        ])
    if reg is not None:
        cargs.extend([
            "--reg",
            *reg
        ])
    if reg_inv is not None:
        cargs.extend([
            "--reg-inv",
            *reg_inv
        ])
    if srcicoorder is not None:
        cargs.extend([
            "--srcicoorder",
            str(srcicoorder)
        ])
    cargs.extend([
        "--trgsubject",
        trg_subject
    ])
    if trgicoorder is not None:
        cargs.extend([
            "--trgicoorder",
            str(trgicoorder)
        ])
    if tval_path is not None:
        cargs.extend([
            "--tval",
            tval_path
        ])
    if tval_xyz is not None:
        cargs.extend([
            "--tval-xyz",
            tval_xyz
        ])
    if tfmt is not None:
        cargs.extend([
            "--tfmt",
            tfmt
        ])
    if trg_dist is not None:
        cargs.extend([
            "--trgdist",
            trg_dist
        ])
    if s is not None:
        cargs.extend([
            "--s",
            s
        ])
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if src_hemi is not None:
        cargs.extend([
            "--srchemi",
            src_hemi
        ])
    if trg_hemi is not None:
        cargs.extend([
            "--trghemi",
            trg_hemi
        ])
    if dual_hemi:
        cargs.append("--dual-hemi")
    if jac:
        cargs.append("--jac")
    if surfreg is not None:
        cargs.extend([
            "--surfreg",
            surfreg
        ])
    if src_surfreg is not None:
        cargs.extend([
            "--srcsurfreg",
            src_surfreg
        ])
    if trg_surfreg is not None:
        cargs.extend([
            "--trgsurfreg",
            trg_surfreg
        ])
    if mapmethod is not None:
        cargs.extend([
            "--mapmethod",
            mapmethod
        ])
    if frame is not None:
        cargs.extend([
            "--frame",
            str(frame)
        ])
    if fwhm_src is not None:
        cargs.extend([
            "--fwhm-src",
            str(fwhm_src)
        ])
    if fwhm_trg is not None:
        cargs.extend([
            "--fwhm-trg",
            str(fwhm_trg)
        ])
    if nsmooth_in is not None:
        cargs.extend([
            "--nsmooth-in",
            str(nsmooth_in)
        ])
    if nsmooth_out is not None:
        cargs.extend([
            "--nsmooth-out",
            str(nsmooth_out)
        ])
    if cortex:
        cargs.append("--cortex")
    if no_cortex:
        cargs.append("--no-cortex")
    if label_src is not None:
        cargs.extend([
            "--label-src",
            execution.input_file(label_src)
        ])
    if label_trg is not None:
        cargs.extend([
            "--label-trg",
            execution.input_file(label_trg)
        ])
    if mul is not None:
        cargs.extend([
            "--mul",
            str(mul)
        ])
    if div is not None:
        cargs.extend([
            "--div",
            str(div)
        ])
    if reshape:
        cargs.append("--reshape")
    if reshape_factor is not None:
        cargs.extend([
            "--reshape-factor",
            str(reshape_factor)
        ])
    if reshape3d:
        cargs.append("--reshape3d")
    if split:
        cargs.append("--split")
    if synth:
        cargs.append("--synth")
    if ones:
        cargs.append("--ones")
    if normvar:
        cargs.append("--normvar")
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if prune:
        cargs.append("--prune")
    if no_prune:
        cargs.append("--no-prune")
    if proj_surf is not None:
        cargs.extend([
            "--proj-surf",
            *proj_surf
        ])
    if proj_norm is not None:
        cargs.extend([
            "--proj-norm",
            *proj_norm
        ])
    if reg_diff is not None:
        cargs.extend([
            "--reg-diff",
            reg_diff
        ])
    if rms is not None:
        cargs.extend([
            "--rms",
            execution.input_file(rms)
        ])
    if rms_mask is not None:
        cargs.extend([
            "--rms-mask",
            execution.input_file(rms_mask)
        ])
    ret = MriSurf2surfOutputs(
        root=execution.output_file("."),
        output_values=execution.output_file(tval_path) if (tval_path is not None) else None,
        trg_distances=execution.output_file(trg_dist) if (trg_dist is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SURF2SURF_METADATA",
    "MriSurf2surfOutputs",
    "mri_surf2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ORIENT_LAS_METADATA = Metadata(
    id="c8cbae7a0ae48bc5ff23e10ecc70110ddd8919ae.boutiques",
    name="orientLAS",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class OrientLasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `orient_las(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_las_image: OutputPathType
    """Output image with LAS orientation"""


def orient_las(
    input_image: InputPathType,
    output_image: str,
    check: bool = False,
    runner: Runner | None = None,
) -> OrientLasOutputs:
    """
    Convert image to LAS orientation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input image in NIfTI format.
        output_image: Output image in NIfTI format with LAS orientation.
        check: Check the match of input and output images using tkregister, and\
            for diffusion data, run dtifit and show tensors with fslview.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `OrientLasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ORIENT_LAS_METADATA)
    cargs = []
    cargs.append("orientLAS")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_image)
    if check:
        cargs.append("--check")
    ret = OrientLasOutputs(
        root=execution.output_file("."),
        output_las_image=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ORIENT_LAS_METADATA",
    "OrientLasOutputs",
    "orient_las",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QATOOLS_PY_METADATA = Metadata(
    id="4d18f6a5ac40096b70dbf7ebf5df96bcffd4d1fe.boutiques",
    name="qatools.py",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class QatoolsPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `qatools_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    summary_csv: OutputPathType
    """Summary CSV file containing quality metrics."""
    screenshots_output: OutputPathType
    """Directory containing screenshots of individual brains if screenshots
    option is selected."""


def qatools_py(
    subjects_dir: str,
    output_dir: str,
    subjects: list[str] | None = None,
    screenshots: bool = False,
    fornix: bool = False,
    outlier: bool = False,
    outlier_table: InputPathType | None = None,
    runner: Runner | None = None,
) -> QatoolsPyOutputs:
    """
    A tool to compute quality metrics from Freesurfer 6.0 analysis results.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects_dir: Subjects directory containing a set of Freesurfer 6.0\
            processed individual datasets.
        output_dir: Output directory for the generated results.
        subjects: List of subject IDs. If omitted, all suitable subdirectories\
            within the subjects directory will be used.
        screenshots: Create screenshots of individual brains.
        fornix: Check fornix segmentation.
        outlier: Run outlier detection.
        outlier_table: Specify normative values for outlier detection.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QatoolsPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QATOOLS_PY_METADATA)
    cargs = []
    cargs.append("qatools.py")
    cargs.extend([
        "--subjects_dir",
        subjects_dir
    ])
    cargs.extend([
        "--output_dir",
        output_dir
    ])
    if subjects is not None:
        cargs.extend([
            "--subjects",
            *subjects
        ])
    if screenshots:
        cargs.append("--screenshots")
    if fornix:
        cargs.append("--fornix")
    if outlier:
        cargs.append("--outlier")
    if outlier_table is not None:
        cargs.extend([
            "--outlier-table",
            execution.input_file(outlier_table)
        ])
    ret = QatoolsPyOutputs(
        root=execution.output_file("."),
        summary_csv=execution.output_file(output_dir + "/summary.csv"),
        screenshots_output=execution.output_file(output_dir + "/screenshots/"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QATOOLS_PY_METADATA",
    "QatoolsPyOutputs",
    "qatools_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SURF2VOLSEG_METADATA = Metadata(
    id="5311f8712d7d6a5ffead8a7275ff29df715e3532.boutiques",
    name="mri_surf2volseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSurf2volsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_surf2volseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_surf2volseg(
    input_segmentation: InputPathType | None = None,
    output_segmentation: str | None = None,
    source_segmentation: InputPathType | None = None,
    lh_white_surf: InputPathType | None = None,
    lh_pial_surf: InputPathType | None = None,
    rh_white_surf: InputPathType | None = None,
    rh_pial_surf: InputPathType | None = None,
    lh_cortex_mask: InputPathType | None = None,
    rh_cortex_mask: InputPathType | None = None,
    fix_presurf_ribbon: InputPathType | None = None,
    label_cortex: bool = False,
    label_wm: bool = False,
    label_wm_unknown: list[float] | None = None,
    lh_annotation: InputPathType | None = None,
    rh_annotation: InputPathType | None = None,
    wmparc_dmax: float | None = None,
    rip_unknown: bool = False,
    hypo_as_wm: bool = False,
    hashres: float | None = None,
    nhops: float | None = None,
    help_flag: bool = False,
    version_flag: bool = False,
    crs_test: list[float] | None = None,
    ctab_file: InputPathType | None = None,
    threads_number: float | None = None,
    runner: Runner | None = None,
) -> MriSurf2volsegOutputs:
    """
    Tool that cleans up presurf aseg cortex and WM, maps cortical labels from an
    annotation into a volume, and labels cerebral WM with closest cortical label.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_segmentation: Full path of input segmentation.
        output_segmentation: Output segmentation file.
        source_segmentation: Source subcortical volume segmentation file\
            (instead of using subcortical segs in input segmentation).
        lh_white_surf: White surface for left hemisphere.
        lh_pial_surf: Pial surface for left hemisphere.
        rh_white_surf: White surface for right hemisphere.
        rh_pial_surf: Pial surface for right hemisphere.
        lh_cortex_mask: Mask for left hemisphere cortex (usually\
            lh.cortex.label).
        rh_cortex_mask: Mask for right hemisphere cortex (usually\
            rh.cortex.label).
        fix_presurf_ribbon: Fix the cortical and WM labels in the input\
            segmentation using ribbon file.
        label_cortex: Relabel cortex in the input segmentation with surface\
            annotation.
        label_wm: Relabel cerebral WM in the input segmentation with surface\
            annotation.
        label_wm_unknown: Relabel unknown WM as lhval and rhval (default is\
            5001 and 5002).
        lh_annotation: Left hemisphere annotation for --label-cortex and\
            --label-wm.
        rh_annotation: Right hemisphere annotation for --label-cortex and\
            --label-wm.
        wmparc_dmax: Max distance (mm) from cortex to be labeled as gyral WM.
        rip_unknown: Do not label WM based on 'unknown' cortical label.
        hypo_as_wm: Label hypointensities as WM (when fixing with ribbon).
        hashres: Surface hash table resolution.
        nhops: Number of surface hops when searching for a nearby annotation.
        help_flag: Print out information on how to use this program.
        version_flag: Print out version and exit.
        crs_test: Test labeling of only the voxel given by column, row, slice\
            (debugging).
        ctab_file: Embed color table in the output.
        threads_number: Run in parallel with the specified number of threads.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSurf2volsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SURF2VOLSEG_METADATA)
    cargs = []
    cargs.append("mri_surf2volseg")
    if input_segmentation is not None:
        cargs.extend([
            "--i",
            execution.input_file(input_segmentation)
        ])
    if output_segmentation is not None:
        cargs.extend([
            "--o",
            output_segmentation
        ])
    if source_segmentation is not None:
        cargs.extend([
            "--src",
            execution.input_file(source_segmentation)
        ])
    if lh_white_surf is not None:
        cargs.extend([
            "--lh-white",
            execution.input_file(lh_white_surf)
        ])
    if lh_pial_surf is not None:
        cargs.extend([
            "--lh-pial",
            execution.input_file(lh_pial_surf)
        ])
    if rh_white_surf is not None:
        cargs.extend([
            "--rh-white",
            execution.input_file(rh_white_surf)
        ])
    if rh_pial_surf is not None:
        cargs.extend([
            "--rh-pial",
            execution.input_file(rh_pial_surf)
        ])
    if lh_cortex_mask is not None:
        cargs.extend([
            "--lh-cortex-mask",
            execution.input_file(lh_cortex_mask)
        ])
    if rh_cortex_mask is not None:
        cargs.extend([
            "--rh-cortex-mask",
            execution.input_file(rh_cortex_mask)
        ])
    if fix_presurf_ribbon is not None:
        cargs.extend([
            "--fix-presurf-with-ribbon",
            execution.input_file(fix_presurf_ribbon)
        ])
    if label_cortex:
        cargs.append("--label-cortex")
    if label_wm:
        cargs.append("--label-wm")
    if label_wm_unknown is not None:
        cargs.extend([
            "--label-wm-unknown",
            *map(str, label_wm_unknown)
        ])
    if lh_annotation is not None:
        cargs.extend([
            "--lh-annot",
            execution.input_file(lh_annotation)
        ])
    if rh_annotation is not None:
        cargs.extend([
            "--rh-annot",
            execution.input_file(rh_annotation)
        ])
    if wmparc_dmax is not None:
        cargs.extend([
            "--wmparc-dmax",
            str(wmparc_dmax)
        ])
    if rip_unknown:
        cargs.append("--rip-unknown")
    if hypo_as_wm:
        cargs.append("--hypo-as-wm")
    if hashres is not None:
        cargs.extend([
            "--hashres",
            str(hashres)
        ])
    if nhops is not None:
        cargs.extend([
            "--nhops",
            str(nhops)
        ])
    if help_flag:
        cargs.append("--help")
    if version_flag:
        cargs.append("--version")
    if crs_test is not None:
        cargs.extend([
            "--crs-test",
            *map(str, crs_test)
        ])
    if ctab_file is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab_file)
        ])
    if threads_number is not None:
        cargs.extend([
            "--threads",
            str(threads_number)
        ])
    ret = MriSurf2volsegOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SURF2VOLSEG_METADATA",
    "MriSurf2volsegOutputs",
    "mri_surf2volseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LINEAR_REGISTER_METADATA = Metadata(
    id="0c492f9c37f4a6d5857023e8af8887cc8eee392c.boutiques",
    name="mri_linear_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLinearRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_linear_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_registered_image: OutputPathType
    """The registered brain image"""


def mri_linear_register(
    input_brain: InputPathType,
    template: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> MriLinearRegisterOutputs:
    """
    A tool for linear registration of MRI brain images to a template.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_brain: Input brain image to be registered.
        template: Template to which the brain image will be registered.
        output_file: Output file name for the registered brain image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLinearRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LINEAR_REGISTER_METADATA)
    cargs = []
    cargs.append("mri_linear_register")
    cargs.append(execution.input_file(input_brain))
    cargs.append(execution.input_file(template))
    cargs.append(output_file)
    ret = MriLinearRegisterOutputs(
        root=execution.output_file("."),
        output_registered_image=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LINEAR_REGISTER_METADATA",
    "MriLinearRegisterOutputs",
    "mri_linear_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_TRANSPOSE_METADATA = Metadata(
    id="e676cb4d2e4814898c733e3dc3fc432bdbe3732f.boutiques",
    name="cifti-transpose",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiTransposeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_transpose(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_transpose(
    cifti_in: InputPathType,
    cifti_out: str,
    opt_mem_limit_limit_gb: float | None = None,
    runner: Runner | None = None,
) -> CiftiTransposeOutputs:
    """
    Transpose a cifti file.
    
    The input must be a 2-dimensional cifti file. The output is a cifti file
    where every row in the input is a column in the output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti file.
        cifti_out: the output cifti file.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiTransposeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_TRANSPOSE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-transpose")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(cifti_out)
    if opt_mem_limit_limit_gb is not None:
        cargs.extend([
            "-mem-limit",
            str(opt_mem_limit_limit_gb)
        ])
    ret = CiftiTransposeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_TRANSPOSE_METADATA",
    "CiftiTransposeOutputs",
    "cifti_transpose",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_PALETTE_METADATA = Metadata(
    id="6600f0fd7050affe6aeef2d792aa2f3d3a26d6e8.boutiques",
    name="metric-palette",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricPalettePosPercent:
    """
    percentage min/max for positive data coloring.
    """
    pos_min__: float
    """the percentile for the least positive data"""
    pos_max__: float
    """the percentile for the most positive data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-pos-percent")
        cargs.append(str(self.pos_min__))
        cargs.append(str(self.pos_max__))
        return cargs


@dataclasses.dataclass
class MetricPaletteNegPercent:
    """
    percentage min/max for negative data coloring.
    """
    neg_min__: float
    """the percentile for the least negative data"""
    neg_max__: float
    """the percentile for the most negative data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neg-percent")
        cargs.append(str(self.neg_min__))
        cargs.append(str(self.neg_max__))
        return cargs


@dataclasses.dataclass
class MetricPalettePosUser:
    """
    user min/max values for positive data coloring.
    """
    pos_min_user: float
    """the value for the least positive data"""
    pos_max_user: float
    """the value for the most positive data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-pos-user")
        cargs.append(str(self.pos_min_user))
        cargs.append(str(self.pos_max_user))
        return cargs


@dataclasses.dataclass
class MetricPaletteNegUser:
    """
    user min/max values for negative data coloring.
    """
    neg_min_user: float
    """the value for the least negative data"""
    neg_max_user: float
    """the value for the most negative data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neg-user")
        cargs.append(str(self.neg_min_user))
        cargs.append(str(self.neg_max_user))
        return cargs


@dataclasses.dataclass
class MetricPaletteThresholding:
    """
    set the thresholding.
    """
    type_: str
    """thresholding setting"""
    test: str
    """show values inside or outside thresholds"""
    min_: float
    """lower threshold"""
    max_: float
    """upper threshold"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-thresholding")
        cargs.append(self.type_)
        cargs.append(self.test)
        cargs.append(str(self.min_))
        cargs.append(str(self.max_))
        return cargs


class MetricPaletteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_palette(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metric_palette(
    metric: str,
    mode: str,
    opt_column_column: str | None = None,
    pos_percent: MetricPalettePosPercent | None = None,
    neg_percent: MetricPaletteNegPercent | None = None,
    pos_user: MetricPalettePosUser | None = None,
    neg_user: MetricPaletteNegUser | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: MetricPaletteThresholding | None = None,
    opt_inversion_type: str | None = None,
    runner: Runner | None = None,
) -> MetricPaletteOutputs:
    """
    Set the palette of a metric file.
    
    The original metric file is overwritten with the modified version. By
    default, all columns of the metric file are adjusted to the new settings,
    use the -column option to change only one column. Mapping settings not
    specified in options will be taken from the first column. The <mode>
    argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric: the metric to modify.
        mode: the mapping mode.
        opt_column_column: select a single column: the column number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricPaletteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_PALETTE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-palette")
    cargs.append(metric)
    cargs.append(mode)
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if pos_percent is not None:
        cargs.extend(pos_percent.run(execution))
    if neg_percent is not None:
        cargs.extend(neg_percent.run(execution))
    if pos_user is not None:
        cargs.extend(pos_user.run(execution))
    if neg_user is not None:
        cargs.extend(neg_user.run(execution))
    if opt_interpolate_interpolate is not None:
        cargs.extend([
            "-interpolate",
            opt_interpolate_interpolate
        ])
    if opt_disp_pos_display is not None:
        cargs.extend([
            "-disp-pos",
            opt_disp_pos_display
        ])
    if opt_disp_neg_display is not None:
        cargs.extend([
            "-disp-neg",
            opt_disp_neg_display
        ])
    if opt_disp_zero_display is not None:
        cargs.extend([
            "-disp-zero",
            opt_disp_zero_display
        ])
    if opt_palette_name_name is not None:
        cargs.extend([
            "-palette-name",
            opt_palette_name_name
        ])
    if thresholding is not None:
        cargs.extend(thresholding.run(execution))
    if opt_inversion_type is not None:
        cargs.extend([
            "-inversion",
            opt_inversion_type
        ])
    ret = MetricPaletteOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_PALETTE_METADATA",
    "MetricPaletteNegPercent",
    "MetricPaletteNegUser",
    "MetricPaletteOutputs",
    "MetricPalettePosPercent",
    "MetricPalettePosUser",
    "MetricPaletteThresholding",
    "metric_palette",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_TOOL_METADATA = Metadata(
    id="aa87ca3b09c13211a78df0adb7766da7160abd1e.boutiques",
    name="cifti_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CiftiToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file for results"""


def cifti_tool(
    input_file: InputPathType,
    as_cext: bool = False,
    disp_cext: bool = False,
    eval_cext: bool = False,
    eval_type: typing.Literal["has_data", "has_bdata", "num_tokens", "show", "show_names", "show_summary", "show_text_data"] | None = None,
    output_file: str | None = None,
    verbose_level: float | None = None,
    verbose_read_level: float | None = None,
    both_verbose_levels: float | None = None,
    runner: Runner | None = None,
) -> CiftiToolOutputs:
    """
    Example tool for reading/writing CIFTI-2 datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Specify input dataset.
        as_cext: Process the input as just an extension.
        disp_cext: Display the CIFTI extension.
        eval_cext: Evaluate the CIFTI extension.
        eval_type: Method for evaluation of axml elements.
        output_file: Where to write output.
        verbose_level: Set the verbose level.
        verbose_read_level: Set verbose level when reading.
        both_verbose_levels: Apply both -verb options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_TOOL_METADATA)
    cargs = []
    cargs.append("cifti_tool")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    if as_cext:
        cargs.append("-as_cext")
    if disp_cext:
        cargs.append("-disp_cext")
    if eval_cext:
        cargs.append("-eval_cext")
    if eval_type is not None:
        cargs.extend([
            "-eval_type",
            eval_type
        ])
    if output_file is not None:
        cargs.extend([
            "-output",
            output_file
        ])
    if verbose_level is not None:
        cargs.extend([
            "-verb",
            str(verbose_level)
        ])
    if verbose_read_level is not None:
        cargs.extend([
            "-verb_read",
            str(verbose_read_level)
        ])
    if both_verbose_levels is not None:
        cargs.extend([
            "-vboth",
            str(both_verbose_levels)
        ])
    ret = CiftiToolOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_TOOL_METADATA",
    "CiftiToolOutputs",
    "cifti_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_COMPUTE_ACORR_METADATA = Metadata(
    id="c87ef9e1a360bff02be52c7cd358fb4259d79971.boutiques",
    name="mris_compute_acorr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisComputeAcorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_compute_acorr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_compute_acorr(
    output_subject: str,
    hemi: str,
    surf: InputPathType,
    curv: InputPathType,
    c1_subjects: list[str],
    c2_subjects: list[str],
    runner: Runner | None = None,
) -> MrisComputeAcorrOutputs:
    """
    Compute the autocorrelation function of a curvature file on a spherical surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_subject: The output subject file.
        hemi: Specify the hemisphere for processing.
        surf: The surface file which must be a spherical surface suitable for\
            computing geodesics.
        curv: The input curvature file.
        c1_subjects: List of subjects from one class.
        c2_subjects: List of subjects from another class.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisComputeAcorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_COMPUTE_ACORR_METADATA)
    cargs = []
    cargs.append("mris_compute_acorr")
    cargs.extend([
        "-o",
        output_subject
    ])
    cargs.append(hemi)
    cargs.append(execution.input_file(surf))
    cargs.append(execution.input_file(curv))
    cargs.extend(c1_subjects)
    cargs.extend(c2_subjects)
    ret = MrisComputeAcorrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_COMPUTE_ACORR_METADATA",
    "MrisComputeAcorrOutputs",
    "mris_compute_acorr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_BRAINVOL_STATS_METADATA = Metadata(
    id="86418de6f4396170ffc91b86701f5d618ef8249c.boutiques",
    name="mri_brainvol_stats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriBrainvolStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_brainvol_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    brain_vol_stats_output: OutputPathType | None
    """Brain volume statistics output file."""


def mri_brainvol_stats(
    subject_id: str,
    xml_string: str | None = None,
    no_surface: bool = False,
    include_segmentation: bool = False,
    output_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriBrainvolStatsOutputs:
    """
    Tool for computing brain volume statistics with FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: The subject ID for which brain volume statistics are\
            computed.
        xml_string: XML string containing input data. The XML is used to define\
            additional parameters for computation.
        no_surface: Flag to specify that surface-based measurements should not\
            be included in the output.
        include_segmentation: Flag to include segmentation information in the\
            brain volume calculations.
        output_file: Output file path to write the brain volume statistics.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriBrainvolStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_BRAINVOL_STATS_METADATA)
    cargs = []
    cargs.append("mri_brainvol_stats")
    cargs.extend([
        "--subject",
        subject_id
    ])
    if xml_string is not None:
        cargs.extend([
            "--xml",
            xml_string
        ])
    if no_surface:
        cargs.append("--no-surface")
    if include_segmentation:
        cargs.append("--seg")
    if output_file is not None:
        cargs.extend([
            "--out",
            execution.input_file(output_file)
        ])
    ret = MriBrainvolStatsOutputs(
        root=execution.output_file("."),
        brain_vol_stats_output=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_BRAINVOL_STATS_METADATA",
    "MriBrainvolStatsOutputs",
    "mri_brainvol_stats",
]
